@@ -15,9 +15,9 @@
 #' @param style Character. One of \dQuote{simple} (default), \dQuote{rmarkdown},
 #'   or \dQuote{grid}. Does not apply to \code{\link{dfSummary}}.
 #' @param plain.ascii Logical. \code{TRUE} by default. Set to \code{FALSE} when
-#'   using summarytools with a rendering tool such as \code{knitr} or when
-#'   creating rmarkdown output files to be converted with Pandoc. Note however
-#'   that its value will automatically be set to \code{FALSE} whenever
+#'   using \strong{summarytools} with a rendering tool such as \code{knitr} or
+#'   when creating rmarkdown output files to be converted with Pandoc. Note 
+#'   however that its value will automatically be set to \code{FALSE} whenever
 #'   \code{style} is set to \dQuote{rmarkdown}).
 #' @param round.digits Numeric. Defaults to \code{2}.
 #' @param headings Logical. Set to \code{FALSE} to remove all headings from
@@ -31,7 +31,7 @@
 #' @param display.labels Logical. \code{TRUE} by default. Set to \code{FALSE} to
 #'   omit data frame and variable labels in the headings section.
 #' @param bootstrap.css Logical. Specifies whether to Include 
-#'   \emph{Bootstrap css} in \emph{html} reports \emph{head} section outputs.
+#'   \emph{Bootstrap css} in \emph{html} reports' \emph{head} section.
 #'   Defaults to \code{TRUE}. Set to \code{FALSE} when using the \dQuote{render}
 #'   method inside a \code{shiny} app to avoid interacting with the app's 
 #'   layout.
@@ -40,6 +40,10 @@
 #' @param escape.pipe Logical. Set to \code{TRUE} if Pandoc conversion is your
 #'   goal and you have unsatisfying results with grid or multiline tables.
 #'   \code{FALSE} by default.
+#' @param char.split Numeric. Maximum number of characters allowed in a column
+#'   heading for \code{\link{descr}} and \code{\link{ctable}} \emph{html} 
+#'   outputs. Any variable name having more than this number of characters
+#'   will be split on two or more lines. Defaults to 12.
 #' @param freq.cumul Logical. Corresponds to the \code{cumul} parameter of
 #'   \code{\link{freq}}. \code{TRUE} by default.
 #' @param freq.totals Logical. Corresponds to the \code{totals} parameter of
@@ -137,6 +141,7 @@ st_options <- function(option                 = NULL,
                        bootstrap.css          = TRUE,
                        custom.css             = NA,
                        escape.pipe            = FALSE,
+                       char.split             = 12,
                        freq.cumul             = TRUE,
                        freq.totals            = TRUE,
                        freq.report.nas        = TRUE,
@@ -207,6 +212,7 @@ st_options <- function(option                 = NULL,
                    "bootstrap.css"          = TRUE,
                    "custom.css"             = NA,
                    "escape.pipe"            = FALSE,
+                   "char.split"             = 12,
                    "freq.cumul"             = TRUE,
                    "freq.totals"            = TRUE,
                    "freq.report.nas"        = TRUE,
